************************
The sherpa.sim.mh module
************************

.. currentmodule:: sherpa.sim.mh

.. automodule:: sherpa.sim.mh

   .. rubric:: Classes

   .. autosummary::
      :toctree: api

      LimitError
      MH
      MetropolisMH
      Sampler
      Walk


   .. rubric:: Functions

   .. autosummary::
      :toctree: api

      dmvnorm
      dmvt

Class Inheritance Diagram
=========================

.. inheritance-diagram:: LimitError MetropolisMH MH Sampler Walk
   :parts: 1
